# The Moz Top 500
Mozs' (NOT to be confused with Mozilla) list of the top 500 domains and pages on the web.

Contains a list of the top 500 web pages ranked by the number of linking root domains. This data is sourced from the Mozcape web index of 818 Billion domains and 6 Trillion pages.

## Update list

```bash
../../tools/generate_moz-top500.py |jq . > list.json
```
